@@ -17,11 +17,14 @@
 # under the License.
 from __future__ import annotations
 
-from multiprocessing.connection import Connection as MultiprocessingConnection
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 from airflow.callbacks.base_callback_sink import BaseCallbackSink
-from airflow.callbacks.callback_requests import CallbackRequest
+
+if TYPE_CHECKING:
+    from multiprocessing.connection import Connection as MultiprocessingConnection
+
+    from airflow.callbacks.callback_requests import CallbackRequest
 
 
 class PipeCallbackSink(BaseCallbackSink):
