@@ -17,11 +17,14 @@
 
 from __future__ import annotations
 
-from typing import Callable, Sequence
+from typing import TYPE_CHECKING, Callable, Sequence
 
-from airflow.decorators.base import TaskDecorator, get_unique_task_id, task_decorator_factory
+from airflow.decorators.base import get_unique_task_id, task_decorator_factory
 from airflow.sensors.python import PythonSensor
 
+if TYPE_CHECKING:
+    from airflow.decorators.base import TaskDecorator
+
 
 class DecoratedSensorOperator(PythonSensor):
     """
@@ -53,7 +56,6 @@ class DecoratedSensorOperator(PythonSensor):
         task_id: str,
         **kwargs,
     ) -> None:
-        kwargs.pop("multiple_outputs")
         kwargs["task_id"] = get_unique_task_id(task_id, kwargs.get("dag"), kwargs.get("task_group"))
         super().__init__(**kwargs)
 
