@@ -15,7 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Implements the ``@task_group`` function decorator.
+"""
+Implements the ``@task_group`` function decorator.
 
 When the decorated function is called, a task group will be created to represent
 a collection of closely related tasks on the same DAG that should be grouped
@@ -37,6 +38,7 @@ from airflow.models.expandinput import (
     ListOfDictsExpandInput,
     MappedArgument,
 )
+from airflow.models.mappedoperator import ensure_xcomarg_return_value
 from airflow.models.taskmixin import DAGNode
 from airflow.models.xcom_arg import XComArg
 from airflow.typing_compat import ParamSpec
@@ -79,10 +81,11 @@ class _TaskGroupFactory(ExpandableFactory, Generic[FParams, FReturn]):
                 group_id = repr(self.tg_kwargs["group_id"])
             except KeyError:
                 group_id = f"at {hex(id(self))}"
-            warnings.warn(f"Partial task group {group_id} was never mapped!")
+            warnings.warn(f"Partial task group {group_id} was never mapped!", stacklevel=1)
 
     def __call__(self, *args: FParams.args, **kwargs: FParams.kwargs) -> DAGNode:
-        """Instantiate the task group.
+        """
+        Instantiate the task group.
 
         This uses the wrapped function to create a task group. Depending on the
         return type of the wrapped function, this either returns the last task
@@ -132,6 +135,11 @@ class _TaskGroupFactory(ExpandableFactory, Generic[FParams, FReturn]):
         self._validate_arg_names("expand", kwargs)
         prevent_duplicates(self.partial_kwargs, kwargs, fail_reason="mapping already partial")
         expand_input = DictOfListsExpandInput(kwargs)
+
+        # Similar to @task, @task_group should not be "mappable" over an XCom with a custom key. This will
+        # raise an exception, rather than having an ambiguous exception similar to the one found in #51109.
+        ensure_xcomarg_return_value(expand_input.value)
+
         return self._create_task_group(
             functools.partial(MappedTaskGroup, expand_input=expand_input),
             **self.partial_kwargs,
@@ -161,6 +169,11 @@ class _TaskGroupFactory(ExpandableFactory, Generic[FParams, FReturn]):
         map_kwargs = (k for k in self.function_signature.parameters if k not in self.partial_kwargs)
 
         expand_input = ListOfDictsExpandInput(kwargs)
+
+        # Similar to @task, @task_group should not be "mappable" over an XCom with a custom key. This will
+        # raise an exception, rather than having an ambiguous exception similar to the one found in #51109.
+        ensure_xcomarg_return_value(expand_input.value)
+
         return self._create_task_group(
             functools.partial(MappedTaskGroup, expand_input=expand_input),
             **self.partial_kwargs,
@@ -195,7 +208,8 @@ def task_group(python_callable: Callable[FParams, FReturn]) -> _TaskGroupFactory
 
 
 def task_group(python_callable=None, **tg_kwargs):
-    """Python TaskGroup decorator.
+    """
+    Python TaskGroup decorator.
 
     This wraps a function into an Airflow TaskGroup. When used as the
     ``@task_group()`` form, all arguments are forwarded to the underlying
