@@ -15,28 +15,30 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Add index on ``log`` table
+"""
+Add index on ``log`` table.
 
 Revision ID: dd25f486b8ea
 Revises: 9635ae0956e7
 Create Date: 2018-08-07 06:41:41.028249
 
 """
+
 from __future__ import annotations
 
 from alembic import op
 
 # revision identifiers, used by Alembic.
-revision = 'dd25f486b8ea'
-down_revision = '9635ae0956e7'
+revision = "dd25f486b8ea"
+down_revision = "9635ae0956e7"
 branch_labels = None
 depends_on = None
-airflow_version = '1.10.2'
+airflow_version = "1.10.2"
 
 
 def upgrade():
-    op.create_index('idx_log_dag', 'log', ['dag_id'], unique=False)
+    op.create_index("idx_log_dag", "log", ["dag_id"], unique=False)
 
 
 def downgrade():
-    op.drop_index('idx_log_dag', table_name='log')
+    op.drop_index("idx_log_dag", table_name="log")
