@@ -14,13 +14,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Add superuser field
+"""
+Add superuser field.
 
 Revision ID: 41f5f12752f8
 Revises: 03bc53e68815
 Create Date: 2018-12-04 15:50:04.456875
 
 """
+
 from __future__ import annotations
 
 import sqlalchemy as sa
