@@ -15,13 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Create a ``session`` table to store web session data
+"""
+Create a ``session`` table to store web session data.
 
 Revision ID: c381b21cb7e4
 Revises: be2bfac3da23
 Create Date: 2022-01-25 13:56:35.069429
 
 """
+
 from __future__ import annotations
 
 import sqlalchemy as sa
@@ -38,7 +40,7 @@ TABLE_NAME = "session"
 
 
 def upgrade():
-    """Apply Create a ``session`` table to store web session data"""
+    """Apply Create a ``session`` table to store web session data."""
     op.create_table(
         TABLE_NAME,
         sa.Column("id", sa.Integer()),
@@ -47,9 +49,10 @@ def upgrade():
         sa.Column("expiry", sa.DateTime()),
         sa.PrimaryKeyConstraint("id"),
         sa.UniqueConstraint("session_id"),
+        if_not_exists=True,
     )
 
 
 def downgrade():
-    """Unapply Create a ``session`` table to store web session data"""
-    op.drop_table(TABLE_NAME)
+    """Unapply Create a ``session`` table to store web session data."""
+    op.drop_table(TABLE_NAME, if_exists=True)
