@@ -18,9 +18,9 @@
 from __future__ import annotations
 
 from enum import Enum
+from typing import TYPE_CHECKING
 
-from sqlalchemy import Column, ForeignKeyConstraint, String, Text, delete, false, select
-from sqlalchemy.orm import Session
+from sqlalchemy import Column, ForeignKeyConstraint, Index, String, Text, delete, false, select
 
 from airflow.api_internal.internal_api_call import internal_api_call
 from airflow.models.base import Base, StringID
@@ -29,6 +29,9 @@ from airflow.utils.retries import retry_db_transaction
 from airflow.utils.session import NEW_SESSION, provide_session
 from airflow.utils.sqlalchemy import UtcDateTime
 
+if TYPE_CHECKING:
+    from sqlalchemy.orm import Session
+
 
 class DagWarning(Base):
     """
@@ -52,6 +55,7 @@ class DagWarning(Base):
             name="dcw_dag_id_fkey",
             ondelete="CASCADE",
         ),
+        Index("idx_dag_warning_dag_id", dag_id),
     )
 
     def __init__(self, dag_id: str, error_type: str, message: str, **kwargs):
