@@ -15,6 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Interact with Amazon EKS, using the boto3 library."""
+
 from __future__ import annotations
 
 import base64
@@ -75,9 +76,29 @@ class NodegroupStates(Enum):
     NONEXISTENT = "NONEXISTENT"
 
 
+COMMAND = """
+            output=$({python_executable} -m airflow.providers.amazon.aws.utils.eks_get_token \
+                --cluster-name {eks_cluster_name} {args} 2>&1)
+
+            if [ $? -ne 0 ]; then
+                echo "Error running the script"
+                exit 1
+            fi
+
+            expiration_timestamp=$(echo "$output" | grep -oP 'expirationTimestamp:\s*\K[^,]+')
+            token=$(echo "$output" | grep -oP 'token:\s*\K[^,]+')
+
+            json_string=$(printf '{{"kind": "ExecCredential","apiVersion": \
+                "client.authentication.k8s.io/v1alpha1","spec": {{}},"status": \
+                {{"expirationTimestamp": "%s","token": "%s"}}}}' "$expiration_timestamp" "$token")
+            echo $json_string
+            """
+
+
 class EksHook(AwsBaseHook):
     """
     Interact with Amazon Elastic Kubernetes Service (EKS).
+
     Provide thin wrapper around :external+boto3:py:class:`boto3.client("eks") <EKS.Client>`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
@@ -101,7 +122,7 @@ class EksHook(AwsBaseHook):
         **kwargs,
     ) -> dict:
         """
-        Creates an Amazon EKS control plane.
+        Create an Amazon EKS control plane.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.create_cluster`
@@ -110,7 +131,6 @@ class EksHook(AwsBaseHook):
         :param roleArn: The Amazon Resource Name (ARN) of the IAM role that provides permissions
           for the Kubernetes control plane to make calls to AWS API operations on your behalf.
         :param resourcesVpcConfig: The VPC configuration used by the cluster control plane.
-
         :return: Returns descriptive information about the created EKS Cluster.
         """
         eks_client = self.conn
@@ -133,7 +153,7 @@ class EksHook(AwsBaseHook):
         **kwargs,
     ) -> dict:
         """
-        Creates an Amazon EKS managed node group for an Amazon EKS Cluster.
+        Create an Amazon EKS managed node group for an Amazon EKS Cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.create_nodegroup`
@@ -143,7 +163,6 @@ class EksHook(AwsBaseHook):
         :param subnets: The subnets to use for the Auto Scaling group that is created for your nodegroup.
         :param nodeRole: The Amazon Resource Name (ARN) of the IAM role to associate with your nodegroup.
         :param tags: Optional tags to apply to your nodegroup.
-
         :return: Returns descriptive information about the created EKS Managed Nodegroup.
         """
         eks_client = self.conn
@@ -181,7 +200,7 @@ class EksHook(AwsBaseHook):
         **kwargs,
     ) -> dict:
         """
-        Creates an AWS Fargate profile for an Amazon EKS cluster.
+        Create an AWS Fargate profile for an Amazon EKS cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.create_fargate_profile`
@@ -191,7 +210,6 @@ class EksHook(AwsBaseHook):
         :param podExecutionRoleArn: The Amazon Resource Name (ARN) of the pod execution role to
             use for pods that match the selectors in the Fargate profile.
         :param selectors: The selectors to match for pods to use this Fargate profile.
-
         :return: Returns descriptive information about the created Fargate profile.
         """
         eks_client = self.conn
@@ -213,13 +231,12 @@ class EksHook(AwsBaseHook):
 
     def delete_cluster(self, name: str) -> dict:
         """
-        Deletes the Amazon EKS Cluster control plane.
+        Delete the Amazon EKS Cluster control plane.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.delete_cluster`
 
         :param name: The name of the cluster to delete.
-
         :return: Returns descriptive information about the deleted EKS Cluster.
         """
         eks_client = self.conn
@@ -231,14 +248,13 @@ class EksHook(AwsBaseHook):
 
     def delete_nodegroup(self, clusterName: str, nodegroupName: str) -> dict:
         """
-        Deletes an Amazon EKS managed node group from a specified cluster.
+        Delete an Amazon EKS managed node group from a specified cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.delete_nodegroup`
 
         :param clusterName: The name of the Amazon EKS Cluster that is associated with your nodegroup.
         :param nodegroupName: The name of the nodegroup to delete.
-
         :return: Returns descriptive information about the deleted EKS Managed Nodegroup.
         """
         eks_client = self.conn
@@ -254,14 +270,13 @@ class EksHook(AwsBaseHook):
 
     def delete_fargate_profile(self, clusterName: str, fargateProfileName: str) -> dict:
         """
-        Deletes an AWS Fargate profile from a specified Amazon EKS cluster.
+        Delete an AWS Fargate profile from a specified Amazon EKS cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.delete_fargate_profile`
 
         :param clusterName: The name of the Amazon EKS cluster associated with the Fargate profile to delete.
         :param fargateProfileName: The name of the Fargate profile to delete.
-
         :return: Returns descriptive information about the deleted Fargate profile.
         """
         eks_client = self.conn
@@ -279,14 +294,13 @@ class EksHook(AwsBaseHook):
 
     def describe_cluster(self, name: str, verbose: bool = False) -> dict:
         """
-        Returns descriptive information about an Amazon EKS Cluster.
+        Return descriptive information about an Amazon EKS Cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_cluster`
 
         :param name: The name of the cluster to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: Returns descriptive information about a specific EKS Cluster.
         """
         eks_client = self.conn
@@ -303,7 +317,7 @@ class EksHook(AwsBaseHook):
 
     def describe_nodegroup(self, clusterName: str, nodegroupName: str, verbose: bool = False) -> dict:
         """
-        Returns descriptive information about an Amazon EKS managed node group.
+        Return descriptive information about an Amazon EKS managed node group.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_nodegroup`
@@ -311,7 +325,6 @@ class EksHook(AwsBaseHook):
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :param nodegroupName: The name of the nodegroup to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: Returns descriptive information about a specific EKS Nodegroup.
         """
         eks_client = self.conn
@@ -335,7 +348,7 @@ class EksHook(AwsBaseHook):
         self, clusterName: str, fargateProfileName: str, verbose: bool = False
     ) -> dict:
         """
-        Returns descriptive information about an AWS Fargate profile.
+        Return descriptive information about an AWS Fargate profile.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_fargate_profile`
@@ -343,7 +356,6 @@ class EksHook(AwsBaseHook):
         :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
         :param fargateProfileName: The name of the Fargate profile to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: Returns descriptive information about an AWS Fargate profile.
         """
         eks_client = self.conn
@@ -366,13 +378,12 @@ class EksHook(AwsBaseHook):
 
     def get_cluster_state(self, clusterName: str) -> ClusterStates:
         """
-        Returns the current status of a given Amazon EKS Cluster.
+        Return the current status of a given Amazon EKS Cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_cluster`
 
         :param clusterName: The name of the cluster to check.
-
         :return: Returns the current status of a given Amazon EKS Cluster.
         """
         eks_client = self.conn
@@ -386,14 +397,13 @@ class EksHook(AwsBaseHook):
 
     def get_fargate_profile_state(self, clusterName: str, fargateProfileName: str) -> FargateProfileStates:
         """
-        Returns the current status of a given AWS Fargate profile.
+        Return the current status of a given AWS Fargate profile.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_fargate_profile`
 
         :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
         :param fargateProfileName: The name of the Fargate profile to check.
-
         :return: Returns the current status of a given AWS Fargate profile.
         """
         eks_client = self.conn
@@ -413,14 +423,13 @@ class EksHook(AwsBaseHook):
 
     def get_nodegroup_state(self, clusterName: str, nodegroupName: str) -> NodegroupStates:
         """
-        Returns the current status of a given Amazon EKS managed node group.
+        Return the current status of a given Amazon EKS managed node group.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.describe_nodegroup`
 
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :param nodegroupName: The name of the nodegroup to check.
-
         :return: Returns the current status of a given Amazon EKS Nodegroup.
         """
         eks_client = self.conn
@@ -441,13 +450,12 @@ class EksHook(AwsBaseHook):
         verbose: bool = False,
     ) -> list:
         """
-        Lists all Amazon EKS Clusters in your AWS account.
+        List all Amazon EKS Clusters in your AWS account.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.list_clusters`
 
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: A List containing the cluster names.
         """
         eks_client = self.conn
@@ -461,14 +469,13 @@ class EksHook(AwsBaseHook):
         verbose: bool = False,
     ) -> list:
         """
-        Lists all Amazon EKS managed node groups associated with the specified cluster.
+        List all Amazon EKS managed node groups associated with the specified cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.list_nodegroups`
 
         :param clusterName: The name of the Amazon EKS Cluster containing nodegroups to list.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: A List of nodegroup names within the given cluster.
         """
         eks_client = self.conn
@@ -482,14 +489,13 @@ class EksHook(AwsBaseHook):
         verbose: bool = False,
     ) -> list:
         """
-        Lists all AWS Fargate profiles associated with the specified cluster.
+        List all AWS Fargate profiles associated with the specified cluster.
 
         .. seealso::
             - :external+boto3:py:meth:`EKS.Client.list_fargate_profiles`
 
         :param clusterName: The name of the Amazon EKS Cluster containing Fargate profiles to list.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: A list of Fargate profile names within a given cluster.
         """
         eks_client = self.conn
@@ -501,12 +507,11 @@ class EksHook(AwsBaseHook):
 
     def _list_all(self, api_call: Callable, response_key: str, verbose: bool) -> list:
         """
-        Repeatedly calls a provided boto3 API Callable and collates the responses into a List.
+        Repeatedly call a provided boto3 API Callable and collates the responses into a List.
 
         :param api_call: The api command to execute.
         :param response_key: Which dict key to collect into the final list.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
-
         :return: A List of the combined results of the provided API call.
         """
         name_collection: list = []
@@ -531,11 +536,21 @@ class EksHook(AwsBaseHook):
         pod_namespace: str | None,
     ) -> Generator[str, None, None]:
         """
-        Writes the kubeconfig file given an EKS Cluster.
+        Write the kubeconfig file given an EKS Cluster.
 
         :param eks_cluster_name: The name of the cluster to generate kubeconfig file for.
         :param pod_namespace: The namespace to run within kubernetes.
         """
+        args = ""
+        if self.region_name is not None:
+            args = args + f" --region-name {self.region_name}"
+
+        if self.aws_conn_id is not None:
+            args = args + f" --aws-conn-id {self.aws_conn_id}"
+
+        # We need to determine which python executable the host is running in order to correctly
+        # call the eks_get_token.py script.
+        python_executable = f"python{sys.version_info[0]}.{sys.version_info[1]}"
         # Set up the client
         eks_client = self.conn
 
@@ -571,28 +586,14 @@ class EksHook(AwsBaseHook):
                     "user": {
                         "exec": {
                             "apiVersion": AUTHENTICATION_API_VERSION,
-                            "command": sys.executable,
+                            "command": "sh",
                             "args": [
-                                "-m",
-                                "airflow.providers.amazon.aws.utils.eks_get_token",
-                                *(
-                                    ["--region-name", self.region_name]
-                                    if self.region_name is not None
-                                    else []
+                                "-c",
+                                COMMAND.format(
+                                    python_executable=python_executable,
+                                    eks_cluster_name=eks_cluster_name,
+                                    args=args,
                                 ),
-                                *(
-                                    ["--aws-conn-id", self.aws_conn_id]
-                                    if self.aws_conn_id is not None
-                                    else []
-                                ),
-                                "--cluster-name",
-                                eks_cluster_name,
-                            ],
-                            "env": [
-                                {
-                                    "name": "AIRFLOW__LOGGING__LOGGING_LEVEL",
-                                    "value": "FATAL",
-                                }
                             ],
                             "interactiveMode": "Never",
                         }
