@@ -22,10 +22,7 @@ import re
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, Sequence
 
-from deprecated.classic import deprecated
-
 from airflow.configuration import conf
-from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.apache.hive.hooks.hive import HiveCliHook
 from airflow.utils import operator_helpers
@@ -131,11 +128,6 @@ class HiveOperator(BaseOperator):
             proxy_user=self.proxy_user,
         )
 
-    @deprecated(reason="use `hook` property instead.", category=AirflowProviderDeprecationWarning)
-    def get_hook(self) -> HiveCliHook:
-        """Get Hive cli hook."""
-        return self.hook
-
     def prepare_template(self) -> None:
         if self.hiveconf_jinja_translate:
             self.hql = re.sub(r"(\$\{(hiveconf:)?([ a-zA-Z0-9_]*)\})", r"{{ \g<3> }}", self.hql)
