@@ -16,12 +16,13 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module is deprecated. Please use :mod:`airflow.providers.cncf.kubernetes.operators.pod` instead."""
+
 from __future__ import annotations
 
 import warnings
 
 from airflow.exceptions import AirflowProviderDeprecationWarning
-from airflow.providers.cncf.kubernetes.operators.pod import *  # noqa
+from airflow.providers.cncf.kubernetes.operators.pod import *  # noqa: F403
 
 warnings.warn(
     "This module is deprecated. Please use `airflow.providers.cncf.kubernetes.operators.pod` instead.",
