@@ -15,7 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains a Google Cloud Vertex AI hook.
+"""
+This module contains a Google Cloud Vertex AI hook.
 
 .. spelling:word-list::
 
