@@ -35,6 +35,9 @@ BIGQUERY_TABLE_LINK = (
     BIGQUERY_BASE_LINK
     + "?referrer=search&project={project_id}&d={dataset_id}&p={project_id}&page=table&t={table_id}"
 )
+BIGQUERY_JOB_DETAIL_LINK = (
+    BIGQUERY_BASE_LINK + "?project={project_id}&ws=!1m5!1m4!1m3!1s{project_id}!2s{job_id}!3s{location}"
+)
 
 
 class BigQueryDatasetLink(BaseGoogleLink):
@@ -78,3 +81,25 @@ class BigQueryTableLink(BaseGoogleLink):
             key=BigQueryTableLink.key,
             value={"dataset_id": dataset_id, "project_id": project_id, "table_id": table_id},
         )
+
+
+class BigQueryJobDetailLink(BaseGoogleLink):
+    """Helper class for constructing BigQuery Job Detail Link."""
+
+    name = "BigQuery Job Detail"
+    key = "bigquery_job_detail"
+    format_str = BIGQUERY_JOB_DETAIL_LINK
+
+    @staticmethod
+    def persist(
+        context: Context,
+        task_instance: BaseOperator,
+        project_id: str,
+        location: str,
+        job_id: str,
+    ):
+        task_instance.xcom_push(
+            context,
+            key=BigQueryJobDetailLink.key,
+            value={"project_id": project_id, "location": location, "job_id": job_id},
+        )
