@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery Data Transfer Service operators."""
+
 from __future__ import annotations
 
 import time
@@ -23,7 +24,6 @@ from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.bigquery_datatransfer_v1 import (
     StartManualTransferRunsResponse,
     TransferConfig,
@@ -31,14 +31,17 @@ from google.cloud.bigquery_datatransfer_v1 import (
     TransferState,
 )
 
-from airflow import AirflowException
 from airflow.configuration import conf
+from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.bigquery_dts import BiqQueryDataTransferServiceHook, get_object_id
 from airflow.providers.google.cloud.links.bigquery_dts import BigQueryDataTransferConfigLink
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.triggers.bigquery_dts import BigQueryDataTransferRunTrigger
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
     from airflow.utils.context import Context
 
 
@@ -92,7 +95,7 @@ class BigQueryCreateDataTransferOperator(GoogleCloudBaseOperator):
         self,
         *,
         transfer_config: dict,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         authorization_code: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
@@ -185,7 +188,7 @@ class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
         self,
         *,
         transfer_config_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -271,7 +274,7 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
         self,
         *,
         transfer_config_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         requested_time_range: dict | None = None,
         requested_run_time: dict | None = None,
@@ -370,7 +373,7 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
             state = transfer_run.state
 
             if self._job_is_done(state):
-                if state == TransferState.FAILED or state == TransferState.CANCELLED:
+                if state in (TransferState.FAILED, TransferState.CANCELLED):
                     raise AirflowException(f"Transfer run was finished with {state} status.")
 
                 result = TransferRun.to_dict(transfer_run)
@@ -391,8 +394,8 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
         return state in finished_job_statuses
 
     def execute_completed(self, context: Context, event: dict):
-        """Method to be executed after invoked trigger in defer method finishes its job."""
-        if event["status"] == "failed" or event["status"] == "cancelled":
+        """Execute after invoked trigger in defer method finishes its job."""
+        if event["status"] in ("failed", "cancelled"):
             self.log.error("Trigger finished its work with status: %s.", event["status"])
             raise AirflowException(event["message"])
 
