@@ -62,7 +62,7 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
         self.location = location
 
     def serialize(self) -> tuple[str, dict[str, Any]]:
-        """Serializes CloudBuildCreateBuildTrigger arguments and classpath."""
+        """Serialize CloudBuildCreateBuildTrigger arguments and classpath."""
         return (
             "airflow.providers.google.cloud.triggers.cloud_build.CloudBuildCreateBuildTrigger",
             {
@@ -76,10 +76,10 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
         )
 
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
-        """Gets current build execution status and yields a TriggerEvent."""
+        """Get current build execution status and yields a TriggerEvent."""
         hook = self._get_async_hook()
-        while True:
-            try:
+        try:
+            while True:
                 # Poll for job execution status
                 cloud_build_instance = await hook.get_cloud_build(
                     id_=self.id_,
@@ -119,10 +119,9 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
                     )
                     return
 
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for Cloud Build completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for Cloud Build completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
     def _get_async_hook(self) -> CloudBuildAsyncHook:
         return CloudBuildAsyncHook(gcp_conn_id=self.gcp_conn_id)
