@@ -23,13 +23,13 @@ Airflow connection of type `wasb` exists. Authorization can be done by supplying
 login (=Storage account name) and password (=KEY), or login and SAS token in the extra
 field (see connection `wasb_default` for an example).
 """
+
 from __future__ import annotations
 
 import logging
 import os
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, Union
-from urllib.parse import urlparse
 
 from asgiref.sync import sync_to_async
 from azure.core.exceptions import HttpResponseError, ResourceExistsError, ResourceNotFoundError
@@ -51,6 +51,7 @@ from airflow.providers.microsoft.azure.utils import (
     add_managed_identity_connection_widgets,
     get_async_default_azure_credential,
     get_sync_default_azure_credential,
+    parse_blob_account_url,
 )
 
 if TYPE_CHECKING:
@@ -61,7 +62,7 @@ AsyncCredentials = Union[AsyncClientSecretCredential, AsyncDefaultAzureCredentia
 
 class WasbHook(BaseHook):
     """
-    Interacts with Azure Blob Storage through the ``wasb://`` protocol.
+    Interact with Azure Blob Storage through the ``wasb://`` protocol.
 
     These parameters have to be passed in Airflow Data Base: account_name and account_key.
 
@@ -81,10 +82,10 @@ class WasbHook(BaseHook):
     conn_type = "wasb"
     hook_name = "Azure Blob Storage"
 
-    @staticmethod
+    @classmethod
     @add_managed_identity_connection_widgets
-    def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form."""
+    def get_connection_form_widgets(cls) -> dict[str, Any]:
+        """Return connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget, BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField, StringField
@@ -102,9 +103,9 @@ class WasbHook(BaseHook):
             "sas_token": PasswordField(lazy_gettext("SAS Token (optional)"), widget=BS3PasswordFieldWidget()),
         }
 
-    @staticmethod
-    def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour."""
+    @classmethod
+    def get_ui_field_behaviour(cls) -> dict[str, Any]:
+        """Return custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port"],
             "relabeling": {
@@ -166,21 +167,7 @@ class WasbHook(BaseHook):
             # connection_string auth takes priority
             return BlobServiceClient.from_connection_string(connection_string, **extra)
 
-        account_url = conn.host if conn.host else f"https://{conn.login}.blob.core.windows.net/"
-        parsed_url = urlparse(account_url)
-
-        if not parsed_url.netloc:
-            if "." not in parsed_url.path:
-                # if there's no netloc and no dots in the path, then user only
-                # provided the Active Directory ID, not the full URL or DNS name
-                account_url = f"https://{conn.login}.blob.core.windows.net/"
-            else:
-                # if there's no netloc but there are dots in the path, then user
-                # provided the DNS name without the https:// prefix.
-                # Azure storage account name can only be 3 to 24 characters in length
-                # https://learn.microsoft.com/en-us/azure/storage/common/storage-account-overview#storage-account-name
-                acc_name = account_url.split(".")[0][:24]
-                account_url = f"https://{acc_name}." + ".".join(account_url.split(".")[1:])
+        account_url = parse_blob_account_url(conn.host, conn.login)
 
         tenant = self._get_field(extra, "tenant_id")
         if tenant:
@@ -226,18 +213,19 @@ class WasbHook(BaseHook):
             **extra,
         )
 
-    def _get_container_client(self, container_name: str) -> ContainerClient:
+    # TODO: rework the interface as it might also return AsyncContainerClient
+    def _get_container_client(self, container_name: str) -> ContainerClient:  # type: ignore[override]
         """
-        Instantiates a container client.
+        Instantiate a container client.
 
         :param container_name: The name of the container
         :return: ContainerClient
         """
         return self.blob_service_client.get_container_client(container_name)
 
-    def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient:
+    def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient | AsyncBlobClient:
         """
-        Instantiates a blob client.
+        Instantiate a blob client.
 
         :param container_name: The name of the blob container
         :param blob_name: The name of the blob. This needs not be existing
@@ -412,7 +400,7 @@ class WasbHook(BaseHook):
         **kwargs,
     ) -> dict[str, Any]:
         """
-        Creates a new blob from a data source with automatic chunking.
+        Create a new blob from a data source with automatic chunking.
 
         :param container_name: The name of the container to upload data
         :param blob_name: The name of the blob to upload. This need not exist in the container
@@ -428,13 +416,14 @@ class WasbHook(BaseHook):
             self.create_container(container_name)
 
         blob_client = self._get_blob_client(container_name, blob_name)
-        return blob_client.upload_blob(data, blob_type, length=length, **kwargs)
+        # TODO: rework the interface as it might also return Awaitable
+        return blob_client.upload_blob(data, blob_type, length=length, **kwargs)  # type: ignore[return-value]
 
     def download(
         self, container_name, blob_name, offset: int | None = None, length: int | None = None, **kwargs
     ) -> StorageStreamDownloader:
         """
-        Downloads a blob to the StorageStreamDownloader.
+        Download a blob to the StorageStreamDownloader.
 
         :param container_name: The name of the container containing the blob
         :param blob_name: The name of the blob to download
@@ -443,7 +432,8 @@ class WasbHook(BaseHook):
         :param length: Number of bytes to read from the stream.
         """
         blob_client = self._get_blob_client(container_name, blob_name)
-        return blob_client.download_blob(offset=offset, length=length, **kwargs)
+        # TODO: rework the interface as it might also return Awaitable
+        return blob_client.download_blob(offset=offset, length=length, **kwargs)  # type: ignore[return-value]
 
     def create_container(self, container_name: str) -> None:
         """
@@ -487,14 +477,14 @@ class WasbHook(BaseHook):
             self._get_container_client(container_name).delete_container()
             self.log.info("Deleted container: %s", container_name)
         except ResourceNotFoundError:
-            self.log.info("Unable to delete container %s (not found)", container_name)
-        except:
-            self.log.info("Error deleting container: %s", container_name)
+            self.log.warning("Unable to delete container %s (not found)", container_name)
+        except Exception:
+            self.log.error("Error deleting container: %s", container_name)
             raise
 
     def delete_blobs(self, container_name: str, *blobs, **kwargs) -> None:
         """
-        Marks the specified blobs or snapshots for deletion.
+        Mark the specified blobs or snapshots for deletion.
 
         :param container_name: The name of the container containing the blobs
         :param blobs: The blobs to delete. This can be a single blob, or multiple values
@@ -586,21 +576,7 @@ class WasbAsyncHook(WasbHook):
             )
             return self.blob_service_client
 
-        account_url = conn.host if conn.host else f"https://{conn.login}.blob.core.windows.net/"
-        parsed_url = urlparse(account_url)
-
-        if not parsed_url.netloc:
-            if "." not in parsed_url.path:
-                # if there's no netloc and no dots in the path, then user only
-                # provided the Active Directory ID, not the full URL or DNS name
-                account_url = f"https://{conn.login}.blob.core.windows.net/"
-            else:
-                # if there's no netloc but there are dots in the path, then user
-                # provided the DNS name without the https:// prefix.
-                # Azure storage account name can only be 3 to 24 characters in length
-                # https://learn.microsoft.com/en-us/azure/storage/common/storage-account-overview#storage-account-name
-                acc_name = account_url.split(".")[0][:24]
-                account_url = f"https://{acc_name}." + ".".join(account_url.split(".")[1:])
+        account_url = parse_blob_account_url(conn.host, conn.login)
 
         tenant = self._get_field(extra, "tenant_id")
         if tenant:
@@ -683,7 +659,8 @@ class WasbAsyncHook(WasbHook):
             return False
         return True
 
-    def _get_container_client(self, container_name: str) -> AsyncContainerClient:
+    # TODO: rework the interface as in parent Hook it returns ContainerClient
+    def _get_container_client(self, container_name: str) -> AsyncContainerClient:  # type: ignore[override]
         """
         Instantiate a container client.
 
