@@ -15,6 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.mongo.hooks.mongo import MongoHook
@@ -26,14 +28,17 @@ if TYPE_CHECKING:
 
 class MongoSensor(BaseSensorOperator):
     """
-    Checks for the existence of a document which
-    matches the given query in MongoDB. Example:
+    Checks for the existence of a document which matches the given query in MongoDB.
 
-    >>> mongo_sensor = MongoSensor(collection="coll",
-    ...                            query={"key": "value"},
-    ...                            mongo_conn_id="mongo_default",
-    ...                            mongo_db="admin",
-    ...                            task_id="mongo_sensor")
+    .. code-block:: python
+
+        mongo_sensor = MongoSensor(
+            collection="coll",
+            query={"key": "value"},
+            mongo_conn_id="mongo_default",
+            mongo_db="admin",
+            task_id="mongo_sensor",
+        )
 
     :param collection: Target MongoDB collection.
     :param query: The query to find the target document.
@@ -42,7 +47,7 @@ class MongoSensor(BaseSensorOperator):
     :param mongo_db: Target MongoDB name.
     """
 
-    template_fields: Sequence[str] = ('collection', 'query')
+    template_fields: Sequence[str] = ("collection", "query")
 
     def __init__(
         self, *, collection: str, query: dict, mongo_conn_id: str = "mongo_default", mongo_db=None, **kwargs
@@ -53,9 +58,9 @@ class MongoSensor(BaseSensorOperator):
         self.query = query
         self.mongo_db = mongo_db
 
-    def poke(self, context: 'Context') -> bool:
+    def poke(self, context: Context) -> bool:
         self.log.info(
             "Sensor check existence of the document that matches the following query: %s", self.query
         )
-        hook = MongoHook(self.mongo_conn_id)
+        hook = MongoHook(mongo_conn_id=self.mongo_conn_id)
         return hook.find(self.collection, self.query, mongo_db=self.mongo_db, find_one=True) is not None
