@@ -29,6 +29,7 @@ if TYPE_CHECKING:
 class OpsgenieCreateAlertOperator(BaseOperator):
     """
     This operator allows you to post alerts to Opsgenie.
+
     Accepts a connection that has an Opsgenie API key as the connection's password.
     This operator sets the domain to conn_id.host, and if not set will default
     to ``https://api.opsgenie.com``.
@@ -101,8 +102,9 @@ class OpsgenieCreateAlertOperator(BaseOperator):
 
     def _build_opsgenie_payload(self) -> dict[str, Any]:
         """
-        Construct the Opsgenie JSON payload. All relevant parameters are combined here
-        to a valid Opsgenie JSON payload.
+        Construct the Opsgenie JSON payload.
+
+        All relevant parameters are combined here to a valid Opsgenie JSON payload.
 
         :return: Opsgenie payload (dict) to send
         """
@@ -129,7 +131,7 @@ class OpsgenieCreateAlertOperator(BaseOperator):
         return payload
 
     def execute(self, context: Context) -> None:
-        """Call the OpsgenieAlertHook to post message"""
+        """Call the OpsgenieAlertHook to post message."""
         self.hook = OpsgenieAlertHook(self.opsgenie_conn_id)
         self.hook.create_alert(self._build_opsgenie_payload())
 
@@ -137,6 +139,7 @@ class OpsgenieCreateAlertOperator(BaseOperator):
 class OpsgenieCloseAlertOperator(BaseOperator):
     """
     This operator allows you to close alerts to Opsgenie.
+
     Accepts a connection that has an Opsgenie API key as the connection's password.
     This operator sets the domain to conn_id.host, and if not set will default
     to ``https://api.opsgenie.com``.
@@ -183,8 +186,9 @@ class OpsgenieCloseAlertOperator(BaseOperator):
 
     def _build_opsgenie_close_alert_payload(self) -> dict[str, Any]:
         """
-        Construct the Opsgenie JSON payload. All relevant parameters are combined here
-        to a valid Opsgenie JSON payload.
+        Construct the Opsgenie JSON payload.
+
+        All relevant parameters are combined here to a valid Opsgenie JSON payload.
 
         :return: Opsgenie close alert payload (dict) to send
         """
@@ -201,7 +205,7 @@ class OpsgenieCloseAlertOperator(BaseOperator):
         return payload
 
     def execute(self, context: Context) -> None:
-        """Call the OpsgenieAlertHook to close alert"""
+        """Call the OpsgenieAlertHook to close alert."""
         self.hook = OpsgenieAlertHook(self.opsgenie_conn_id)
         self.hook.close_alert(
             identifier=self.identifier,
@@ -214,6 +218,7 @@ class OpsgenieCloseAlertOperator(BaseOperator):
 class OpsgenieDeleteAlertOperator(BaseOperator):
     """
     This operator allows you to delete alerts in Opsgenie.
+
     Accepts a connection that has an Opsgenie API key as the connection's password.
     This operator sets the domain to conn_id.host, and if not set will default
     to ``https://api.opsgenie.com``.
@@ -254,7 +259,7 @@ class OpsgenieDeleteAlertOperator(BaseOperator):
         self.source = source
 
     def execute(self, context: Context) -> None:
-        """Call the OpsgenieAlertHook to delete alert"""
+        """Call the OpsgenieAlertHook to delete alert."""
         hook = OpsgenieAlertHook(self.opsgenie_conn_id)
         hook.delete_alert(
             identifier=self.identifier,
